library(ggplot2)
library(dplyr)
library(tidyr)
library(broom)
library(mgcv)
library(grid)
library(lattice)
library(Matrix)
library(ggthemes)

d <- read.csv#(Texture_Slabbed.csv)


#Derive geometric mean of particle size diameter following Schirazi and Boersma 1984 SSSAJ

d$sand <- as.numeric(d$sand)
d$clay <- as.numeric(d$clay)

d$silt <- 100-(d$sand+d$clay)
d$silt <- as.numeric(d$silt)
d$particle <- exp(0.01*((d$sand*log(1.025))+(d$silt*log(0.026))+(d$clay*log(0.001))))

dsets <- split(d, d$city)




# after looking at data i think you should use generalized additive models (gams)
# you can add simple random effects to these right out of the box (see below) and they fit
# smoothed curves to data that change locally, as yours seem to. (you can do more complex stuff
# with gamm, too but unless you want to fit something across all cities you dont' need to get into that.
# GAMs are the smooth that ggplot2 usuualy fits if there are > 1000 data points
# so they're what produced the smooths in the plots i made above.


## Atlanta particle size model and plot
d.Atlanta.ps <- dsets[[1]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Atlanta.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                data=d.Atlanta.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Atlanta.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Atlanta.ps)

# implications
summary(m.Atlanta.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Atlanta.ps <- broom::augment(m.Atlanta.ps)
ggplot(p.Atlanta.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Atlanta.ps <- expand.grid(type=unique(d.Atlanta.ps$type),
                  top=seq(min(d.Atlanta.ps$top),
                          max(d.Atlanta.ps$top),
                          length.out=100))
f.Atlanta.ps.p <- predict(m.Atlanta.ps, newdata=f.Atlanta.ps, exclude="s(id)",
               newdata.guaranteed=TRUE, se.fit=TRUE)
f.Atlanta.ps$.fitted_wo_re <- f.Atlanta.ps.p$fit
f.Atlanta.ps$.se <- f.Atlanta.ps.p$se.fit

Atlanta.particle <- ggplot(f.Atlanta.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Atlanta") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Atlanta.ps,file="Atlanta_f_ps.csv",col.names=T, sep=",")


## Camden particle size model and plot
d.Camden.ps <- dsets[[2]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Camden.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Camden.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Camden.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Camden.ps)

# implications
summary(m.Camden.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Camden.ps <- broom::augment(m.Camden.ps)
ggplot(p.Camden.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Camden.ps <- expand.grid(type=unique(d.Camden.ps$type),
                            top=seq(min(d.Camden.ps$top),
                                    max(d.Camden.ps$top),
                                    length.out=100))
f.Camden.ps.p <- predict(m.Camden.ps, newdata=f.Camden.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Camden.ps$.fitted_wo_re <- f.Camden.ps.p$fit
f.Camden.ps$.se <- f.Camden.ps.p$se.fit

Camden.particle <- ggplot(f.Camden.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Camden") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Camden.ps,file="Camden_f_ps.csv",col.names=T, sep=",")

## Cincinnati particle size model and plot
d.Cincinnati.ps <- dsets[[3]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Cincinnati.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Cincinnati.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Cincinnati.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Cincinnati.ps)

# implications
summary(m.Cincinnati.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Cincinnati.ps <- broom::augment(m.Cincinnati.ps)
ggplot(p.Cincinnati.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Cincinnati.ps <- expand.grid(type=unique(d.Cincinnati.ps$type),
                            top=seq(min(d.Cincinnati.ps$top),
                                    max(d.Cincinnati.ps$top),
                                    length.out=100))
f.Cincinnati.ps.p <- predict(m.Cincinnati.ps, newdata=f.Cincinnati.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Cincinnati.ps$.fitted_wo_re <- f.Cincinnati.ps.p$fit
f.Cincinnati.ps$.se <- f.Cincinnati.ps.p$se.fit

Cincinnati.particle <- ggplot(f.Cincinnati.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Cincinnati") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Cincinnati.ps,file="Cincinnati_f_ps.csv",col.names=T, sep=",")


## Cleveland particle size model and plot
d.Cleveland.ps <- dsets[[4]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Cleveland.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Cleveland.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Cleveland.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Cleveland.ps)

# implications
summary(m.Cleveland.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Cleveland.ps <- broom::augment(m.Cleveland.ps)
ggplot(p.Cleveland.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Cleveland.ps <- expand.grid(type=unique(d.Cleveland.ps$type),
                            top=seq(min(d.Cleveland.ps$top),
                                    max(d.Cleveland.ps$top),
                                    length.out=100))
f.Cleveland.ps.p <- predict(m.Cleveland.ps, newdata=f.Cleveland.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Cleveland.ps$.fitted_wo_re <- f.Cleveland.ps.p$fit
f.Cleveland.ps$.se <- f.Cleveland.ps.p$se.fit

Cleveland.particle <- ggplot(f.Cleveland.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Cleveland") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Cleveland.ps,file="Cleveland_f_ps.csv",col.names=T, sep=",")


## Detroit particle size model and plot
d.Detroit.ps <- dsets[[5]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Detroit.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Detroit.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Detroit.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Detroit.ps)

# implications
summary(m.Detroit.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Detroit.ps <- broom::augment(m.Detroit.ps)
ggplot(p.Detroit.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Detroit.ps <- expand.grid(type=unique(d.Detroit.ps$type),
                            top=seq(min(d.Detroit.ps$top),
                                    max(d.Detroit.ps$top),
                                    length.out=100))
f.Detroit.ps.p <- predict(m.Detroit.ps, newdata=f.Detroit.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Detroit.ps$.fitted_wo_re <- f.Detroit.ps.p$fit
f.Detroit.ps$.se <- f.Detroit.ps.p$se.fit

Detroit.particle <- ggplot(f.Detroit.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Detroit") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Detroit.ps,file="Detroit_f_ps.csv",col.names=T, sep=",")


## New Orleans particle size model and plot
d.NewOrleans.ps <- dsets[[6]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.NewOrleans.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.NewOrleans.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.NewOrleans.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.NewOrleans.ps)

# implications
summary(m.NewOrleans.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.NewOrleans.ps <- broom::augment(m.NewOrleans.ps)
ggplot(p.NewOrleans.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.NewOrleans.ps <- expand.grid(type=unique(d.NewOrleans.ps$type),
                            top=seq(min(d.NewOrleans.ps$top),
                                    max(d.NewOrleans.ps$top),
                                    length.out=100))
f.NewOrleans.ps.p <- predict(m.NewOrleans.ps, newdata=f.NewOrleans.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.NewOrleans.ps$.fitted_wo_re <- f.NewOrleans.ps.p$fit
f.NewOrleans.ps$.se <- f.NewOrleans.ps.p$se.fit

NewOrleans.particle <- ggplot(f.NewOrleans.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("New Orleans") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.NewOrleans.ps,file="NewOrleans_f_ps.csv",col.names=T, sep=",")


## Omaha particle size model and plot
d.Omaha.ps <- dsets[[7]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Omaha.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Omaha.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Omaha.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Omaha.ps)

# implications
summary(m.Omaha.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Omaha.ps <- broom::augment(m.Omaha.ps)
ggplot(p.Omaha.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Omaha.ps <- expand.grid(type=unique(d.Omaha.ps$type),
                            top=seq(min(d.Omaha.ps$top),
                                    max(d.Omaha.ps$top),
                                    length.out=100))
f.Omaha.ps.p <- predict(m.Omaha.ps, newdata=f.Omaha.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Omaha.ps$.fitted_wo_re <- f.Omaha.ps.p$fit
f.Omaha.ps$.se <- f.Omaha.ps.p$se.fit

Omaha.particle <- ggplot(f.Omaha.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Omaha") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Omaha.ps,file="Omaha_f_ps.csv",col.names=T, sep=",")


## Phoenix particle size model and plot
d.Phoenix.ps <- dsets[[8]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Phoenix.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Phoenix.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Phoenix.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Phoenix.ps)

# implications
summary(m.Phoenix.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Phoenix.ps <- broom::augment(m.Phoenix.ps)
ggplot(p.Phoenix.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Phoenix.ps <- expand.grid(type=unique(d.Phoenix.ps$type),
                            top=seq(min(d.Phoenix.ps$top),
                                    max(d.Phoenix.ps$top),
                                    length.out=100))
f.Phoenix.ps.p <- predict(m.Phoenix.ps, newdata=f.Phoenix.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Phoenix.ps$.fitted_wo_re <- f.Phoenix.ps.p$fit
f.Phoenix.ps$.se <- f.Phoenix.ps.p$se.fit

Phoenix.particle <- ggplot(f.Phoenix.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Phoenix") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Phoenix.ps,file="Phoenix_f_ps.csv",col.names=T, sep=",")


## Portland particle size model and plot
d.Portland.ps <- dsets[[9]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Portland.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Portland.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Portland.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Portland.ps)

# implications
summary(m.Portland.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Portland.ps <- broom::augment(m.Portland.ps)
ggplot(p.Portland.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Portland.ps <- expand.grid(type=unique(d.Portland.ps$type),
                            top=seq(min(d.Portland.ps$top),
                                    max(d.Portland.ps$top),
                                    length.out=100))
f.Portland.ps.p <- predict(m.Portland.ps, newdata=f.Portland.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Portland.ps$.fitted_wo_re <- f.Portland.ps.p$fit
f.Portland.ps$.se <- f.Portland.ps.p$se.fit

Portland.particle <- ggplot(f.Portland.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Portland") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Portland.ps,file="Portland_f_ps.csv",col.names=T, sep=",")


## San Juan particle size model and plot
d.SanJuan.ps <- dsets[[10]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.SanJuan.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.SanJuan.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.SanJuan.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.SanJuan.ps)

# implications
summary(m.SanJuan.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.SanJuan.ps <- broom::augment(m.SanJuan.ps)
ggplot(p.SanJuan.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.SanJuan.ps <- expand.grid(type=unique(d.SanJuan.ps$type),
                            top=seq(min(d.SanJuan.ps$top),
                                    max(d.SanJuan.ps$top),
                                    length.out=100))
f.SanJuan.ps.p <- predict(m.SanJuan.ps, newdata=f.SanJuan.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.SanJuan.ps$.fitted_wo_re <- f.SanJuan.ps.p$fit
f.SanJuan.ps$.se <- f.SanJuan.ps.p$se.fit

SanJuan.particle <- ggplot(f.SanJuan.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("San Juan") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.SanJuan.ps,file="SanJuan_f_ps.csv",col.names=T, sep=",")


## Tacoma particle size model and plot
d.Tacoma.ps <- dsets[[11]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Tacoma.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Tacoma.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Tacoma.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Tacoma.ps)

# implications
summary(m.Tacoma.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Tacoma.ps <- broom::augment(m.Tacoma.ps)
ggplot(p.Tacoma.ps) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Tacoma.ps <- expand.grid(type=unique(d.Tacoma.ps$type),
                            top=seq(min(d.Tacoma.ps$top),
                                    max(d.Tacoma.ps$top),
                                    length.out=100))
f.Tacoma.ps.p <- predict(m.Tacoma.ps, newdata=f.Tacoma.ps, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Tacoma.ps$.fitted_wo_re <- f.Tacoma.ps.p$fit
f.Tacoma.ps$.se <- f.Tacoma.ps.p$se.fit

Tacoma.particle <- ggplot(f.Tacoma.ps) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Tacoma") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Tacoma.ps,file="Tacoma_f_ps.csv",col.names=T, sep=",")


## Combine all cities' model output for the global analysis
f.Atlanta.ps$city <- "Atlanta"
f.Camden.ps$city <- "Camden"
f.Cincinnati.ps$city <- "Cincinnati"
f.Cleveland.ps$city <- "Cleveland"
f.Detroit.ps$city <- "Detroit"
f.NewOrleans.ps$city <- "New Orleans"
f.Omaha.ps$city <- "Omaha"
f.Phoenix.ps$city <- "Phoenix"
f.Portland.ps$city <- "Portland"
f.SanJuan.ps$city <- "San Juan"
f.Tacoma.ps$city <- "Tacoma"

d.Global.ps <- bind_rows(f.Atlanta.ps,f.Camden.ps,f.Cincinnati.ps,
                         f.Cleveland.ps,f.Detroit.ps,f.NewOrleans.ps,
                         f.Omaha.ps,f.Phoenix.ps,f.Portland.ps,
                         f.SanJuan.ps,f.Tacoma.ps)

d.Global.ps$particle <- 10^d.Global.ps$.fitted_wo_re

# d.Global.ps$city <- as.factor(d.Global.ps$city)
# d.Global.ps$top <- as.numeric(d.Global.ps$top)
# d.Global.ps$type <- as.factor(d.Global.ps$type)
# d.Global.ps$particle <- as.numeric(d.Global.ps$particle)
# 
# d.Global.ps <- read.csv("//aa.ad.epa.gov/ORD/CIN/USERS/MAIN/A-E/dherrman/Net MyDocuments/_MovedData/R Project Directory/Convergence/Global_d_ps.csv")

#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Global.ps <- mgcv::gam(log10(particle) ~ type + s(top, by=type, bs="tp") + s(city, bs="re"),
                          data=d.Global.ps, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Global.ps,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Global.ps)

# implications
summary(m.Global.ps)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Global.ps <- broom::augment(m.Global.ps)
ggplot(p.Global.ps) + geom_boxplot(aes(city, .resid))

# look at predicted urban and rural profiles
f.Global.ps <- expand.grid(type=unique(d.Global.ps$type),
                            top=seq(min(d.Global.ps$top),
                                    max(d.Global.ps$top),
                                    length.out=100))
f.Global.ps.p <- predict(m.Global.ps, newdata=f.Global.ps, exclude="s(city)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Global.ps$.fitted_wo_re <- f.Global.ps.p$fit
f.Global.ps$.se <- f.Global.ps.p$se.fit

Global.particle <- ggplot(f.Global.ps, aes(top, .fitted_wo_re, fill=type, color=type)) +
  geom_ribbon(aes(ymin = .fitted_wo_re - 2 * .se,
                  ymax = .fitted_wo_re + 2 * .se),
              alpha = 1/3, color=NA, show.legend=F)+
  geom_line(size=1, show.legend=F) +
  scale_x_reverse(lim=c(150,-5)) +
  theme_bw()+
  coord_flip()+
  labs(y="Particle size (mm)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(-3,0),
                     breaks=c(-3,-2,-1,0),
                     labels=c("0.001","0.01","0.1","1"))+
  scale_color_manual(values=c("red","blue"))+
  scale_fill_manual(values=c("red","blue"))+
  geom_line(data=f.Atlanta.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Camden.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Cincinnati.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Cleveland.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Detroit.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.NewOrleans.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Omaha.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Phoenix.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Portland.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.SanJuan.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Tacoma.ps, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_text(x=5, y=-2, label="Urban", color="blue", size=3)+
  geom_text(x=5, y=-1, label="Reference", color="red", size=3)

tiff("GRL_Figure_Global PS profile.tif", res=1000, compression = "lzw", height=4.56, width=3.42, units="in")
Global.particle
dev.off()

## Get model summaries
summary(m.Global.ps)
summary(m.Atlanta.ps)
summary(m.Camden.ps)
summary(m.Cincinnati.ps)
summary(m.Cleveland.ps)
summary(m.Detroit.ps)
summary(m.NewOrleans.ps)
summary(m.Omaha.ps)
summary(m.Phoenix.ps)
summary(m.Portland.ps)
summary(m.SanJuan.ps)
summary(m.Tacoma.ps)



